==> xfxbase-2.4.1.tar.gz: lib/xfxbase.dart <==
library xfxbase;

import 'dart:async';
import 'dart:io';
import 'dart:isolate';
import 'dart:typed_data';
import 'package:collection/collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:observable/observable.dart' as Observable;
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xfxbase/XBL/XAzureRest.dart';
import 'package:xfxbase/_XFX/_XFx_Elenco.dart';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:xtoolspackage/XLibStorage.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:syncfusion_flutter_gauges/gauges.dart';

import 'XFDataItem.dart';
import '_XFX/XF_Col.dart';
part 'XAppData_Base.dart';
part 'XApp.dart';
part 'XfxMenu.dart';
part 'XArea.dart';
part 'XMainPage_Base.dart';
part 'XTabItem.dart';

get textStyleDescr => XStyles.xStyTextForSubDescr();
get textStyleLabel => XStyles.xStyTextForSubLabel();
late XAzureStorage azureStorage;
late PackageInfo? packageInfo;

calcSconto(TextEditingController controller, String value) {
  if (controller.text == "") {
    return value.replaceAll("+", "");
  } else {
    return value;
  }
}

calcCell_Negative(XCol xCol, TextEditingController controller, numForCalc) {
  var x;
  if (controller.text == "") {
  } else {
    if (xCol.dataType == double) {
      x = double.parse(controller.text);
      if (x > 0) {
        var res = (x - numForCalc);
        if (res < 0) {
        } else {
          controller.text = res.toString();
        }
      }
    } else if (xCol.dataType == int) {
      x = int.parse(controller.text);
      if (x > 0) {
        var res = (x - numForCalc);
        if (res < 0) {
        } else {
          controller.text = res.toString();
        }
      }
    } else {
      x = int.parse(controller.text);
      if (x > 0) {
        var res = (x - numForCalc);
        if (res < 0) {
        } else {
          controller.text = res.toString();
        }
      }
    }
  }

  return x;
}

calcCell_Positive(XCol xCol, TextEditingController controller, numForCalc) {
  var x;
  if (xCol.dataType == double) {
    if (controller.text == "") {
      controller.text = (numForCalc).toString();
    } else {
      x = double.parse(controller.text);
      controller.text = (x + numForCalc).toString();
    }
  } else if (xCol.dataType == int) {
    if (controller.text == "") {
      controller.text = (numForCalc).toString();
    } else {
      x = int.parse(controller.text);
      controller.text = (x + numForCalc).toString();
    }
  } else {
    if (controller.text == "") {
      controller.text = (numForCalc).toString();
    } else {
      x = int.parse(controller.text);
      controller.text = (x + numForCalc).toString();
    }
  }
  return x;
}

XBtnbase builderXEditDialog_BTNs(TextEditingController controller, BuildContext context, String valueAndLabel, bool isSconto, void Function(void Function()) parentSetState, {XCol? xCol}) {
  return XBtnbase(
      padding: EdgeInsets.all(1),
      width: 45 * XUtils.kforScale,
      label_Style: XStyles.xStyTextForSubLabel(valueAndLabel.contains("+")
          ? Colors.green
          : valueAndLabel.contains("-") || valueAndLabel == ("C")
              ? Colors.red
              : Colors.green),
      label: valueAndLabel,
      backGroundColor: Colors.grey[700],
      onPressed: () {
        if (valueAndLabel == "C") {
          controller.text = "";
          FocusScope.of(context).unfocus();
        } else {
          if (isSconto) {
            parentSetState(() {
              controller.text += calcSconto(controller, valueAndLabel);
            });
          } else {
            if (valueAndLabel.contains("-")) {
              calcCell_Negative(xCol!, controller, int.parse(valueAndLabel.replaceFirst("-", "")));
            } else {
              calcCell_Positive(xCol!, controller, int.parse(valueAndLabel.replaceFirst("+", "")));
            }
          }
          controller.selection = TextSelection(baseOffset: controller.text.length, extentOffset: controller.text.length);
        }
      });
}

Widget xEditDialog_NumberValue(TextEditingController textController, BuildContext context, void Function(void Function()) parentSetState, {bool btnNumberActive = false}) {
  return Column(mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.start, children: [
    btnNumberActive
        ? Row(mainAxisAlignment: MainAxisAlignment.center, children: [
            Expanded(
                child: Wrap(spacing: 6, runSpacing: 6, children: [
              // builderXEditDialog_BTNs(item, textController, "-20", false, parentSetState!, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-10", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-5", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-3", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-1", false, parentSetState, xCol: xCol),
            ]))
          ])
        : Container(height: 0),
    SizedBox(height: btnNumberActive ? 10 : 1),
    Row(mainAxisAlignment: MainAxisAlignment.center, children: [
      Expanded(
          child: XTextFormField(
        height: null,
        textAlign: TextAlign.start,
        controller: textController,
        contentPadding: EdgeInsets.all(7),
        keyboardType: TextInputType.number,
        inputFormatters: [FilteringTextInputFormatter.deny(RegExp("[- /,\\\\]"))],
      )),
      SizedBox(width: 10),
      builderXEditDialog_BTNs(textController, context, "C", false, parentSetState),
    ]),
    SizedBox(height: btnNumberActive ? 10 : 1),
    btnNumberActive
        ? Row(mainAxisAlignment: MainAxisAlignment.center, children: [
            Expanded(
                child: Wrap(spacing: 6, runSpacing: 6, children: [
              // builderXEditDialog_BTNs(item, textController, "+20", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+10", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+5", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+3", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+1", false, parentSetState, xCol: xCol),
            ]))
          ])
        : Container(height: 0)
  ]);
}

==> xfxbase-2.6.5.tar.gz: lib/xfxbase.dart <==
library xfxbase;

import 'dart:async';
import 'dart:isolate';
import 'package:collection/collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:observable/observable.dart' as Observable;
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:universal_io/io.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xfxbase/XBL/XAzureRest.dart';
import 'package:camera/camera.dart';

import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:xtoolspackage/XLibStorage.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:syncfusion_flutter_gauges/gauges.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

import 'XFDataItem.dart';
import '_XFX/XF_Col.dart';
// part 'XAppData_Base.dart';
part 'XAppBase.dart';
part 'XfxMenu.dart';
// part 'XArea.dart';
// part 'XMainPage_Base.dart';

get textStyleDescr => XStyles.xStyTextForSubDescr();
get textStyleLabel => XStyles.xStyTextForSubLabel();
late XAzureStorage azureStorage;
late PackageInfo? packageInfo;

calcSconto(TextEditingController controller, String value) {
  if (controller.text == "") {
    return value.replaceAll("+", "");
  } else {
    return value;
  }
}

calcCell_Negative(XCol xCol, TextEditingController controller, numForCalc) {
  var x;
  if (controller.text == "") {
  } else {
    if (xCol.dataType == double) {
      x = double.parse(controller.text);
      if (x > 0) {
        var res = (x - numForCalc);
        if (res < 0) {
        } else {
          controller.text = res.toString();
        }
      }
    } else if (xCol.dataType == int) {
      x = int.parse(controller.text);
      if (x > 0) {
        var res = (x - numForCalc);
        if (res < 0) {
        } else {
          controller.text = res.toString();
        }
      }
    } else {
      x = int.parse(controller.text);
      if (x > 0) {
        var res = (x - numForCalc);
        if (res < 0) {
        } else {
          controller.text = res.toString();
        }
      }
    }
  }

  return x;
}

calcCell_Positive(XCol xCol, TextEditingController controller, numForCalc) {
  var x;
  if (xCol.dataType == double) {
    if (controller.text == "") {
      controller.text = (numForCalc).toString();
    } else {
      x = double.parse(controller.text);
      controller.text = (x + numForCalc).toString();
    }
  } else if (xCol.dataType == int) {
    if (controller.text == "") {
      controller.text = (numForCalc).toString();
    } else {
      x = int.parse(controller.text);
      controller.text = (x + numForCalc).toString();
    }
  } else {
    if (controller.text == "") {
      controller.text = (numForCalc).toString();
    } else {
      x = int.parse(controller.text);
      controller.text = (x + numForCalc).toString();
    }
  }
  return x;
}

XBtnbase builderXEditDialog_BTNs(TextEditingController controller, BuildContext context, String valueAndLabel, bool isSconto, void Function(void Function()) parentSetState, {XCol? xCol}) {
  return XBtnbase(
      padding: EdgeInsets.all(1),
      width: 45 * XUtils.kforScale,
      label_Style: XStyles.xStyTextForSubLabel(valueAndLabel.contains("+")
          ? Colors.green
          : valueAndLabel.contains("-") || valueAndLabel == ("C")
              ? Colors.red
              : Colors.green),
      label: valueAndLabel,
      backGroundColor: Colors.grey[700],
      onPressed: () {
        if (valueAndLabel == "C") {
          controller.text = "";
          FocusScope.of(context).unfocus();
        } else {
          if (isSconto) {
            parentSetState(() {
              controller.text += calcSconto(controller, valueAndLabel);
            });
          } else {
            if (valueAndLabel.contains("-")) {
              calcCell_Negative(xCol!, controller, int.parse(valueAndLabel.replaceFirst("-", "")));
            } else {
              calcCell_Positive(xCol!, controller, int.parse(valueAndLabel.replaceFirst("+", "")));
            }
          }
          controller.selection = TextSelection(baseOffset: controller.text.length, extentOffset: controller.text.length);
        }
      });
}

Widget xEditDialog_NumberValue(TextEditingController textController, BuildContext context, void Function(void Function()) parentSetState, {bool btnNumberActive = false}) {
  return Column(mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.start, children: [
    btnNumberActive
        ? Row(mainAxisAlignment: MainAxisAlignment.center, children: [
            Expanded(
                child: Wrap(spacing: 6, runSpacing: 6, children: [
              // builderXEditDialog_BTNs(item, textController, "-20", false, parentSetState!, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-10", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-5", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-3", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "-1", false, parentSetState, xCol: xCol),
            ]))
          ])
        : Container(height: 0),
    SizedBox(height: btnNumberActive ? 10 : 1),
    Row(mainAxisAlignment: MainAxisAlignment.center, children: [
      Expanded(
          child: XTextFormField(
        height: null,
        textAlign: TextAlign.start,
        controller: textController,
        contentPadding: EdgeInsets.all(7),
        keyboardType: TextInputType.number,
        inputFormatters: [FilteringTextInputFormatter.deny(RegExp("[- /,\\\\]"))],
      )),
      SizedBox(width: 10),
      builderXEditDialog_BTNs(textController, context, "C", false, parentSetState),
    ]),
    SizedBox(height: btnNumberActive ? 10 : 1),
    btnNumberActive
        ? Row(mainAxisAlignment: MainAxisAlignment.center, children: [
            Expanded(
                child: Wrap(spacing: 6, runSpacing: 6, children: [
              // builderXEditDialog_BTNs(item, textController, "+20", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+10", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+5", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+3", false, parentSetState, xCol: xCol),
              // builderXEditDialog_BTNs(item, textController, "+1", false, parentSetState, xCol: xCol),
            ]))
          ])
        : Container(height: 0)
  ]);
}
